==> vue-shufflejs-plugin-0.2.2.tar.gz: vue-shufflejs-plugin-0.2.2/src/index.js <==
import VueShuffle from './components/VueShuffle'
import VueShuffleNavbar from './components/VueShuffleNavbar'
import VueShuffleGrid from './components/VueShuffleGrid'
import LoadingIndicator from './components/LoadingIndicator'

import ShuffleItemAttributes from './directives/shuffle-item-attributes'

import { sanitize } from './filters'

import 'intersection-observer'

const VueShuffleJsPlugin = {
  install (Vue, options) {
    /**
     * Add filters
     */
    Vue.filter('sanitize', sanitize)

    /**
     * Install plugin components
     */
    Vue.component(VueShuffle.name, VueShuffle)
    Vue.component(VueShuffleNavbar.name, VueShuffleNavbar)
    Vue.component(VueShuffleGrid.name, VueShuffleGrid)
    Vue.component(LoadingIndicator.name, LoadingIndicator)

    /**
     * Install plugin directives
     */
    Vue.directive('shuffle-item-attributes', ShuffleItemAttributes)

    /**
     * Add component lifecycle hooks or properties
     * Call Vue.mixin() here to inject functionality into all components
     * Anything added to a mixin will be injected into all components
     * created() method runs when the component is created
     * mounted() method runs when the component is added to the DOM
     */
    /* Vue.mixin({
      created () {
        console.log('component created...', this)
      },
      mounted () {
        console.log('component mounted...', this)
      }
    }) */
  }
}

/**
 * Automatic installation if Vue has been added to the global scope
 */
if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.use(VueShuffleJsPlugin)
}

export default VueShuffleJsPlugin

==> vue-shufflejs-plugin-0.2.4.tar.gz: vue-shufflejs-plugin-0.2.4/src/index.js <==
import VueShuffle from './components/VueShuffle'
import VueShuffleNavbar from './components/VueShuffleNavbar'
import VueShuffleGrid from './components/VueShuffleGrid'
import LoadingIndicator from './components/LoadingIndicator'

import ShuffleItemAttributes from './directives/shuffle-item-attributes'

import VueI18n from 'vue-i18n'
import messages from './assets/locale/messages.json'

import { sanitize } from './filters'
import 'intersection-observer'

const VueShuffleJsPlugin = {
  install (Vue, options = {}) {
    /**
     * Add plugins
     * Check if "i18n" is installed, if not install it or merge locale messages
     */
    if (!Vue.prototype.hasOwnProperty('$i18n')) {
      Vue.use(VueI18n)
      Vue.prototype._i18n = new VueI18n({
        locale: window.localStorage.language || window.language || 'en',
        messages
      })
    }

    /**
     * Add filters
     */
    Vue.filter('sanitize', sanitize)

    /**
     * Install plugin components
     */
    Vue.component(VueShuffle.name, VueShuffle)
    Vue.component(VueShuffleNavbar.name, VueShuffleNavbar)
    Vue.component(VueShuffleGrid.name, VueShuffleGrid)
    Vue.component(LoadingIndicator.name, LoadingIndicator)

    /**
     * Install plugin directives
     */
    Vue.directive('shuffle-item-attributes', ShuffleItemAttributes)

    /**
     * Add component lifecycle hooks or properties
     * Call Vue.mixin() here to inject functionality into all components
     * Anything added to a mixin will be injected into all components
     * beforeCreate() method runs before the component is created
     * created() method runs when the component is created
     * mounted() method runs when the component is added to the DOM
     */
    Vue.mixin({
      beforeCreate () {
        if (this.$options.i18n) {
          // console.info('$i18n is installed...', this.$i18n.locale)
          const locale = this.$i18n.locale
          this.$i18n.mergeLocaleMessage(locale, messages[locale])
        } else {
          // console.info('$i18n is not installed...')
        }
      }
    })
  }
}

/**
 * Automatic installation if Vue has been added to the global scope
 */
if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.use(VueShuffleJsPlugin)
}

export default VueShuffleJsPlugin
